pub enum MessageProcessingResult {
ApplicationMessage(Message),
Proposal(UpdateGroupResult),
ExternalJoinProposal,
Commit,
Unprocessable,
}Expand description
MessageProcessingResult covers the full spectrum of responses that we can get back from attempting to process a message
Variants
ApplicationMessage(Message)
An application message (this is usually a message in a chat)
Proposal(UpdateGroupResult)
Proposal message
ExternalJoinProposal
External Join Proposal
Commit
Commit message
Unprocessable
Unprocessable message